@@ -24,17 +24,8 @@
 #include <libosso.h>
 #include <hildon/hildon.h>
 #include <dbus/dbus.h>
-#if 0
 #include <mce/mode-names.h>
 #include <mce/dbus-names.h>
-#else
-#define MCE_SERVICE "com.nokia.mce"
-#define MCE_SIGNAL_IF "com.nokia.mce.signal"
-#define MCE_REQUEST_IF "com.nokia.mce.request"
-#define MCE_REQUEST_PATH "/com/nokia/mce/request"
-#define MCE_DEVICE_ORIENTATION_SIG "sig_device_orientation_ind"
-#define MCE_ORIENTATION_PORTRAIT "portrait"
-#endif
 #define MCE_SIGNAL_MATCH "type='signal'," \
         "interface='" MCE_SIGNAL_IF   "'," \
         "member='" MCE_DEVICE_ORIENTATION_SIG "'"
